/* graphics.h  */

/* VIS-5D version 3.0 */

/*
vis5d program for visualizing five dimensional gridded data sets
Copyright (C) 1990, 1991, 1992  Bill Hibbard, Brian Paul, Dave Santek,
and Andre Battaiola.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 1, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/



#ifndef GRAPHICS_H
#define GRAPHICS_H

#include "x.h"


#if defined(stellar)
#  define AA_PASSES 9
#elif defined(sgi)
#  define AA_PASSES 9
#else
#  define AA_PASSES 1
#endif



extern int Width, Height;        /* current window size */
extern int ScrWidth, ScrHeight;  /* screen size */
extern float AspectRatio;
extern int FontHeight;
extern int FontDescent;
extern int HQR_available;        /* High-Quality rendering available? */



/*** init_graphics ****************************************************
   Initialize the graphics module.
**********************************************************************/
extern void init_graphics();



/*** make_window ******************************************************
   Make a 3-D graphics window.
   Input:  display - which X display to open window on
           title - window title string
           xpos,ypos - position in pixel from upper-left corner
           width, height - width and height of window in pixels
           fontname - name of GL or X font to use
           fontsize - height of GL font to use
   Return:  X window pointer or NULL.
**********************************************************************/
extern Window make_window();
/*
Display *dpy;
char *title;
int xpos, ypos;
int width, height;
*/




/*** clear_window *****************************************************
   Clear the graphics window.  This is called prior to rendering
   a frame.
**********************************************************************/
extern void clear_window();




/*** update_window ****************************************************
   Update the 3-D window.  This called when finished rendering a frame.
**********************************************************************/
extern void update_window();



extern void set_2d();

extern void set_3d();


extern void set_color();
/*
unsigned long color;
*/



/*** set_depthcue *****************************************************
   Set the line depth cueing flag on or off.
**********************************************************************/
extern void set_depthcue();
/*
int onoff;
*/



/*** set_line_width ***************************************************
   Set the width of lines.
   Input:  w - width in pixels.
**********************************************************************/
extern void set_line_width();
/*
int w;
*/


/*** set_frontclip ****************************************************
   Set the position of the user-defined front clipping plane.
**********************************************************************/
extern void set_frontclip();
/*
float d;
*/


extern void set_box_clipping();



/*** set_pretty *******************************************************
   Set pretty rendering mode on or off.
   Stellar:  This function is used to select antialiasing and multi-pass
             transparency.
   SGI:  This function selects line antialiasing.
   Input: onoff - 1 = on, 0 = off.
**********************************************************************/
extern void set_pretty();
/*
int onoff;
*/



/*** start_aa_pass ****************************************************
   Start antialiasing pass n, where n is in [0..8].
**********************************************************************/
extern void start_aa_pass();
/*
int n;
*/




/*** end_aa_pass ******************************************************
   End an antialiasing pass n, where n is in [0..8].
**********************************************************************/
extern void end_aa_pass();
/*
int n;
*/




/*** start_hqtrans_pass ***********************************************
   Start a high-quality transparency rendering pass.
**********************************************************************/
extern void start_hqtrans_pass();




/*** end_hqtrans_pass *************************************************
   End a high-quality transparency rendering pass.
   Return:  number of unresolved pixels (used to determine when enough
            rendering passes have been made.
**********************************************************************/
extern int end_hqtrans_pass();




/*** polytrinorm ******************************************************
   Draw a polytriangle strip with normals.
**********************************************************************/
extern void polytrinorm();
/*
float vert[][3];
float norm[][3];
int n;
*/


/*** polytri **********************************************************
   Draw a polytriangle strip without shading.
**********************************************************************/
extern void polytri();
/*
float vert[][3];
float norm[][3];
int n;
*/



extern void polyline();
/*
float vert[][3];
int n;
*/




/*** disjointpolyline *************************************************
   Draw a series of disjoint 3-D lines.
**********************************************************************/
extern void disjointpolyline();
/*
float vert[][3];
int n;
*/



/*** quadmesh *********************************************************
   Draw a quadrilateral mesh.
**********************************************************************/
extern void quadmesh();
/*
float vert[][3];
unsigned int color[];
int rows, cols;
*/



/*** quadmeshnorm *****************************************************
   Draw a quadrilateral mesh with normals and vertex colors.
**********************************************************************/
extern void quadmeshnorm();
/*
float vert[][3];
float norm[][3];
unsigned int color[];
int rows, cols;
*/



/*** polyline2d *******************************************************
   Draw a 2-D poly line.  Coordinates are in pixels with the origin
   in the upper-left corner of the window.  NOTE:  vertices are shorts.
**********************************************************************/
extern void polyline2d();
/*
short vert[][2];
int n;
*/



/*** draw_rect ********************************************************
   Draw a rectangle in 2-D.
**********************************************************************/
extern void draw_rect();
/*
int x1, y1, x2, y2;
*/


/*** draw_text ********************************************************
   Draw a text string at a position.
**********************************************************************/
extern void draw_text();
/*
int xpos, ypos;
char *str;
*/


/*** text_width *******************************************************
   Return the width of a text string in pixels.
**********************************************************************/
extern int text_width();
/*
char *str;
*/




#endif

